      SUBROUTINE TYPE210(TIME,XIN,OUT,T,DTDT,PAR,INFO,ICNTRL,*)

!**********************************************************************************************
! NODE - This type is a Utility component that represents a node in the information flow
!         diagram represented in the Studio.
!
! Revision History:
!  2006.02.06 - DAA  Component written.			       
!
!----------------------------------------------------------------
!	    NODE
!----------------------------------------------------------------
!
! PARAMETERS:
!  mode   = 1 - Left for future upgrades
!  n_in = Number of inputs to be passed
!	
!
! INPUTS
!  XIN(n_in) - Array containing the variables to be passed
!
! OUTPUTS
!  OUT(n_in) - Array with variables to be passed to the next component
!
!**********************************************************************************************
! Copyright  2006 Solar Energy Laboratory, University of Wisconsin-Madison. All rights reserved.
!-----------------------------------------------------------------------------------------------------------------------
!    REQUIRED BY THE MULTI-DLL VERSION OF TRNSYS
      !DEC$ATTRIBUTES DLLEXPORT :: TYPE210
!-----------------------------------------------------------------------------------------------------------------------



!-----------------------------------------------------------------------------------------------------------------------
	USE TrnsysFunctions
	USE TrnsysConstants, ONLY:  nMaxOutputs
!-----------------------------------------------------------------------------------------------------------------------


!-----------------------------------------------------------------------------------------------------------------------
!    TRNSYS DECLARATIONS
    IMPLICIT NONE						!REQUIRES THE USER TO DEFINE ALL VARIABLES BEFORE USING THEM
	DOUBLE PRECISION XIN				!THE ARRAY FROM WHICH THE INPUTS TO THIS TYPE WILL BE RETRIEVED
	DOUBLE PRECISION OUT				!THE ARRAY WHICH WILL BE USED TO STORE THE OUTPUTS FROM THIS TYPE
	DOUBLE PRECISION TIME				!THE CURRENT SIMULATION TIME - YOU MAY USE THIS VARIABLE BUT DO NOT SET IT!
	DOUBLE PRECISION PAR				!THE ARRAY FROM WHICH THE PARAMETERS FOR THIS TYPE WILL BE RETRIEVED
	DOUBLE PRECISION STORED     		!THE STORAGE ARRAY FOR HOLDING VARIABLES FROM TIMESTEP TO TIMESTEP
	DOUBLE PRECISION T					!AN ARRAY CONTAINING THE RESULTS FROM THE DIFFERENTIAL EQUATION SOLVER
	DOUBLE PRECISION DTDT				!AN ARRAY CONTAINING THE DERIVATIVES TO BE PASSED TO THE DIFF.EQ. SOLVER
    INTEGER*4 INFO(15)					!THE INFO ARRAY STORES AND PASSES VALUABLE INFORMATION TO AND FROM THIS TYPE
	INTEGER*4 NPMAX,NIMAX,NOUTMAX,ND	!VARIABLES FOR THE MAXIMUM NUMBER OF PARAMETERS,INPUTS,OUTPUTS AND DERIVATIVES
	INTEGER*4 NPAR,NIN,NDER				!VARIABLES FOR THE CORRECT NUMBER OF PARAMETERS,INPUTS,OUTPUTS AND DERIVATIVES
	INTEGER*4 IUNIT,ITYPE				!THE UNIT NUMBER AND TYPE NUMBER FOR THIS COMPONENT
	INTEGER*4 ICNTRL					!AN ARRAY FOR HOLDING VALUES OF CONTROL FUNCTIONS WITH THE NEW SOLVER
	INTEGER*4 NSTORED					!THE NUMBER OF VARIABLES THAT WILL BE PASSED INTO AND OUT OF STORAGE
    CHARACTER*3 OCHECK					!AN ARRAY TO BE FILLED WITH THE CORRECT VARIABLE TYPES FOR THE OUTPUTS
	CHARACTER*3 YCHECK					!AN ARRAY TO BE FILLED WITH THE CORRECT VARIABLE TYPES FOR THE INPUTS
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    USER DECLARATIONS - SET THE MAXIMUM NUMBER OF PARAMETERS (NP), INPUTS (NI),
!    OUTPUTS (NOUT), AND DERIVATIVES (ND) THAT MAY BE SUPPLIED FOR THIS TYPE
    PARAMETER (NPAR=2,NIMAX=nMaxOutputs,NOUTMAX=nMaxOutputs,ND=0,NSTORED=0)
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    REQUIRED TRNSYS DIMENSIONS
    DIMENSION XIN(NIMAX),OUT(NOUTMAX),PAR(NPAR),YCHECK(NIMAX), &
     OCHECK(NOUTMAX),STORED(NSTORED),T(ND),DTDT(ND)
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    DECLARATIONS AND DEFINITIONS FOR THE USER-VARIABLES

	INTEGER MODE
	DOUBLE PRECISION TIME0,TFINAL,DELT

!-----------------------------------------------------------------------------------------------------------------------
!    TRNSYS FUNCTIONS
    TIME0=getSimulationStartTime()
    TFINAL=getSimulationStopTime()
    DELT=getSimulationTimeStep()
!-----------------------------------------------------------------------------------------------------------------------
!    SET THE VERSION INFORMATION FOR TRNSYS
    IF(INFO(7).EQ.-2) THEN
	  INFO(12)=16
	  RETURN 1
	ENDIF
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    DO ALL THE VERY LAST CALL OF THE SIMULATION MANIPULATIONS HERE
    IF (INFO(8).EQ.-1) THEN
	  RETURN 1
	ENDIF
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    PERFORM ANY "AFTER-ITERATION" MANIPULATIONS THAT ARE REQUIRED
     IF(INFO(13).GT.0) THEN
	   RETURN 1
	 ENDIF
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    DO ALL THE VERY FIRST CALL OF THE SIMULATION MANIPULATIONS HERE
     IF (INFO(7).EQ.-1) THEN
!       RETRIEVE THE UNIT NUMBER AND TYPE NUMBER FOR THIS COMPONENT FROM THE INFO ARRAY
       IUNIT=INFO(1)
	   ITYPE=INFO(2)

!       SET SOME INFO ARRAY VARIABLES TO TELL THE TRNSYS ENGINE HOW THIS TYPE IS TO WORK
       INFO(9) = 1				
	   INFO(10) = 0	

       mode = JFIX(PAR(1)+0.1)	!Left for future upgrades
	   NIN = JFIX(PAR(2)+0.1)
       INFO(6) = NIN

       CALL TYPECK(1,INFO,NIN,NPAR,0)

!       RETURN TO THE CALLING PROGRAM
       RETURN 1

     ENDIF
!--------------------------------------------------------------------------------------------

!--------------------------------------------------------------------------------------------
!    DO ALL OF THE INITIAL TIMESTEP MANIPULATIONS HERE - THERE ARE NO ITERATIONS AT THE INTIAL TIME
     IF (TIME.LT.(TIME0+DELT/2.D0)) THEN

!       SET THE UNIT NUMBER FOR FUTURE CALLS
       IUNIT=INFO(1)
       ITYPE=INFO(2)

!       READ IN THE VALUES OF THE PARAMETERS IN SEQUENTIAL ORDER
       MODE = JFIX(PAR(1)+0.1)
       NIN = JFIX(PAR(2)+0.1)

!       INITIALIZE OUTPUTS
       OUT(1:NIN) = XIN(1:NIN)

       RETURN 1
     ENDIF
!C-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    *** ITS AN ITERATIVE CALL TO THIS COMPONENT ***
!-----------------------------------------------------------------------------------------------------------------------

!-----------------------------------------------------------------------------------------------------------------------
!    RE-READ THE PARAMETERS IF ANOTHER UNIT OF THIS TYPE HAS BEEN CALLED SINCE THE LAST TIME THE PARAMETERS
!    WERE READ IN
     IF(INFO(1).NE.IUNIT) THEN

!      SET THE UNIT NUMBER FOR FUTURE CALLS
       IUNIT=INFO(1)
       ITYPE=INFO(2)

!       READ IN THE VALUES OF THE PARAMETERS IN SEQUENTIAL ORDER
       MODE = JFIX(PAR(1)+0.1)
       NIN = JFIX(PAR(2)+0.1)
     ENDIF

	 OUT(1:NIN) = XIN(1:NIN)

     RETURN 1

      
   END
